function [centredspectrum] = centerfreqs(spec1side,nf)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This code is distributed as part of the source-code package 
%                   acoustic_modelling_foldy_v.4.1_seg 
% that accompanies Galetti et al. (2013). The package can be downloaded 
% from the Geophysics source-code archive at 
%                   http://software.seg.org/2013/0003
% Use of this code is subject to acceptance of the terms and conditions
% that can be found at http://software.seg.org/disclaimer.txt 
% Copyright 2013 by The Society of Exploration Geophysicists (SEG)
% Reference:
% Galetti, E., Halliday, D., Curtis, A. (2013) A simple and exact acoustic 
% wavefield modelling code for data processing, imaging and interferometry 
% applications. Geophysics.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% [centredspectrum] = centerfreqs(spec1side,nf)
%
% Obtains a centred frequency spectrum [-nf:-1;0;1:nf-1] from the one-sided
% spectrum spec1side having nf non-zero frequencies along dim1.
%
%
% Erica Galetti, May 2012
% Contact: erica.galetti@ed.ac.uk

if size(spec1side,1)~=nf
    error('Number of frequencies in spectrum does not match number of frequencies in input.')
end

centredspectrum = fftshift([zeros(1,size(spec1side,2),size(spec1side,3));spec1side(1:nf-1,:,:)./sqrt(2);real(spec1side(nf,:,:));flipdim(conj(spec1side(1:nf-1,:,:)),1)./sqrt(2)],1);

end
