function [rick] = rickerwavl_time(time,fc)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This code is distributed as part of the source-code package 
%                   acoustic_modelling_foldy_v.4.1_seg 
% that accompanies Galetti et al. (2013). The package can be downloaded 
% from the Geophysics source-code archive at 
%                   http://software.seg.org/2013/0003
% Use of this code is subject to acceptance of the terms and conditions
% that can be found at http://software.seg.org/disclaimer.txt 
% Copyright 2013 by The Society of Exploration Geophysicists (SEG)
% Reference:
% Galetti, E., Halliday, D., Curtis, A. (2013) A simple and exact acoustic 
% wavefield modelling code for data processing, imaging and interferometry 
% applications. Geophysics.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% [rick] = rickerwavl_time(time,fc)
%
% Calculates a Ricker wavelet of central frequency "fc" over the time
% interval "time".
%
% Input:
%   time    time vector
%   fc      central frequency of Ricker wavelet
%
%
% Erica Galetti, July 2012
% Contact: erica.galetti@ed.ac.uk

rick = (1-2*pi^2*fc^2*(time).^2).*exp(-(pi*fc*(time)).^2);

end
