function [coords,newval] = makecircbound(rad,ds,fix,x0,y0)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This code is distributed as part of the source-code package 
%                   acoustic_modelling_foldy_v.4.1_seg 
% that accompanies Galetti et al. (2013). The package can be downloaded 
% from the Geophysics source-code archive at 
%                   http://software.seg.org/2013/0003
% Use of this code is subject to acceptance of the terms and conditions
% that can be found at http://software.seg.org/disclaimer.txt 
% Copyright 2013 by The Society of Exploration Geophysicists (SEG)
% Reference:
% Galetti, E., Halliday, D., Curtis, A. (2013) A simple and exact acoustic 
% wavefield modelling code for data processing, imaging and interferometry 
% applications. Geophysics.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Creates a circular boundary of points in the x-y plane centred at x0,y0.
% 
% Input:    rad     radius of circle
%           ds      spacing of points on the circle
%           fix     'fixrad' fix radius
%                   'fixds' fix ds
% Output:	coords  x and y coordinates of circle
%           newval  new value of non-fixed quantity
%
%
% Erica Galetti, July 2012
% Contact: erica.galetti@ed.ac.uk
	

npts = round(2*pi*rad/ds);
theta = linspace(0, 2*pi, npts+1);

if strcmp(fix,'fixrad')
    dsnew = 2*pi*rad/npts;
    x = rad.*cos(theta(1:end-1));
    y = rad.*sin(theta(1:end-1));
    newval = dsnew;
elseif strcmp(fix,'fixds')
    radnew = ds*npts/(2*pi);
    x = radnew.*cos(theta(1:end-1));
    y = radnew.*sin(theta(1:end-1));
    newval = radnew;
end

coords(1:length(x),1) = x + x0; % boundary x-coordinate
coords(1:length(x),2) = y + y0; % boundary y-coordinate

end
