%% %%% Figures in GEOPHYSICS format %%% %%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This code is distributed as part of the source-code package 
%                   acoustic_modelling_foldy_v.4.1_seg 
% that accompanies Galetti et al. (2013). The package can be downloaded 
% from the Geophysics source-code archive at 
%                   http://software.seg.org/2013/0003
% Use of this code is subject to acceptance of the terms and conditions
% that can be found at http://software.seg.org/disclaimer.txt 
% Copyright 2013 by The Society of Exploration Geophysicists (SEG)
% Reference:
% Galetti, E., Halliday, D., Curtis, A. (2013) A simple and exact acoustic 
% wavefield modelling code for data processing, imaging and interferometry 
% applications. Geophysics.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Figures 4,5

clear all
close all

% Read data from ascii files
AB_int_full_t_2sided = dlmread('fig_4_5_data/AB_int_full_t_2sided.txt','\t');
AB_int_mon_t_2sided = dlmread('fig_4_5_data/AB_int_mon_t_2sided.txt','\t');
AB_true_t = dlmread('fig_4_5_data/AB_true_t.txt','\t');
AB_true_t_2sided = dlmread('fig_4_5_data/AB_true_t_2sided.txt','\t');
AB_true_t_2sided_comp = dlmread('fig_4_5_data/AB_true_t_2sided_comp.txt','\t');
time2 = dlmread('fig_4_5_data/time2.txt','\t');
srx = dlmread('fig_4_5_data/srx.txt','\t');
rcx = dlmread('fig_4_5_data/rcx.txt','\t');
scats = dlmread('fig_4_5_data/scats.txt','\t');


scrnsz = get(0,'screensize');
amaxt=max(max([abs(AB_true_t_2sided),abs(AB_int_mon_t_2sided),abs(AB_int_full_t_2sided)]));


% Plot geometry
fig6=figure;
fig6w=3.33;
fig6h=3.33;
set(fig6,'units','inches','Pos',[1 1 fig6w fig6h])
% Plot
hold on
src=plot(srx(1:6:end,1),srx(1:6:end,2),'k*','markersize',6);
rec=plot(rcx(:,1),rcx(:,2),'kv','markersize',6,'markerfacecolor','k');
scat=plot(scats(:,1),scats(:,2),'ko','markersize',6,'markerfacecolor','w');
axis equal
axis([min(srx(:,1)-50) max(srx(:,1)+50) min(srx(:,2)-50) max(srx(:,2)+50)])
box on
set(gca,'fontsize',8,'XTick',-500:250:500,'YTick',-500:250:500)
xlabel ('x (m)','fontsize',8)
ylabel ('y (m)','fontsize',8)
text(rcx(1,1),rcx(1,2)-50,'A','fontsize',8,'FontAngle','italic','horizontalalignment','center')
text(rcx(2,1),rcx(2,2)-50,'B','fontsize',8,'FontAngle','italic','horizontalalignment','center')


% Plot results: true GF and interferometric GFs 
% Time domain, causal part only and zoomed-in areas
fig7=figure;
fig7w=4.33;
fig7h=6;
set(fig7,'units','inches','Pos',[5 1 fig7w fig7h])
% Complete traces
main=axes('position',[0.1 0.1 0.8 0.8]);
sca=0.8/(2*amaxt);
sct=0.8/(0.5*max(time2));
hold on
set(gca,'ColorOrder',[0 0 0;0.2 0.2 0.2;0.6 0.6 0.6])
hold all
true=plot(time2,AB_true_t_2sided_comp,'-','linewidth',2);
int_mon=plot(time2,AB_int_mon_t_2sided,'--','linewidth',2);
int_full=plot(time2,AB_int_full_t_2sided,'-.','linewidth',2);
axis([0 0.4*max(time2) -amaxt amaxt])
box on
set(gca,'fontsize',8)
%%%%% Following 8 lines adapted from http://www.mathworks.fr/matlabcentral/newsreader/view_thread/112386
oldLabels = str2num(get(gca,'YTickLabel'));
exp = 10^3;
newLabels = num2str(oldLabels);
set(gca,'YTickLabel',newLabels,'units','normalized');
posAxes = get(gca,'position');
textBox = annotation('textbox','linestyle','none','margin',1,'string',['x 10^{' sprintf('%d',log10(1./exp)) '}']);
posAn = get(textBox,'position');
set(textBox,'fontsize',8,'position',[posAxes(1) posAxes(2)+posAxes(4) posAn(3) posAn(4)],'VerticalAlignment','bottom','HorizontalAlignment','left');
%%%%%
xlabel ('Time (s)','fontsize',8)
ylabel ('Amplitude (pressure)','fontsize',8)
leg=legend([true int_mon int_full],'True trace','Interferometric trace (monopole)','Interferometric trace (full)','location','southoutside');
% Zoom 1
z1ax=[0.209 0.2105 0.979*amaxt 0.984*amaxt];
z1=axes('position',[0.35 0.65 (z1ax(2)-z1ax(1))*sct*140 (z1ax(4)-z1ax(3))*sca*100]);
set(gca,'ColorOrder',[0 0 0;0.2 0.2 0.2;0.6 0.6 0.6])
hold all
plot(time2,AB_true_t_2sided_comp,'-',time2,AB_int_mon_t_2sided,'--',time2,AB_int_full_t_2sided,'-.','linewidth',2);
axis(z1ax)
box on
set(z1,'fontsize',8,'XTick',[0.209;0.2105],'XTickLabel',[0.209;0.2105])
%%%%% Following 8 lines adapted from http://www.mathworks.fr/matlabcentral/newsreader/view_thread/112386
oldLabels = str2num(get(gca,'YTickLabel'));
exp = 10^3;
newLabels = num2str(oldLabels);
set(gca,'YTickLabel',newLabels,'units','normalized');
posAxes = get(gca,'position');
textBox = annotation('textbox','linestyle','none','margin',1,'string',['x 10^{' sprintf('%d',log10(1./exp)) '}']);
posAn = get(textBox,'position');
set(textBox,'fontsize',8,'position',[posAxes(1) posAxes(2)+posAxes(4) posAn(3) posAn(4)],'VerticalAlignment','bottom','HorizontalAlignment','left');
%%%%%
% Zoom 2
z2ax=[0.385 0.405 -0.17*amaxt -0.12*amaxt];
z2=axes('position',[0.38 0.28 (z2ax(2)-z2ax(1))*sct*10 (z2ax(4)-z2ax(3))*sca*10]);
set(gca,'ColorOrder',[0 0 0;0.2 0.2 0.2;0.6 0.6 0.6])
hold all
plot(time2,AB_true_t_2sided_comp,'-',time2,AB_int_mon_t_2sided,'--',time2,AB_int_full_t_2sided,'-.','linewidth',2);
axis(z2ax)
box on
set(z2,'fontsize',8,'XTick',[0.390;0.400],'XTickLabel',[0.390;0.400])
%%%%% Following 8 lines adapted from http://www.mathworks.fr/matlabcentral/newsreader/view_thread/112386
oldLabels = str2num(get(gca,'YTickLabel'));
exp = 10^4;
newLabels = num2str(oldLabels);
set(gca,'YTickLabel',newLabels,'units','normalized');
posAxes = get(gca,'position');
textBox = annotation('textbox','linestyle','none','margin',1,'string',['x 10^{' sprintf('%d',log10(1./exp)) '}']);
posAn = get(textBox,'position');
set(textBox,'fontsize',8,'position',[posAxes(1) posAxes(2)+posAxes(4) posAn(3) posAn(4)],'VerticalAlignment','bottom','HorizontalAlignment','left');
%%%%%
% Zoom 3
z3ax=[0.555 0.575 -0.12*amaxt -0.07*amaxt];
z3=axes('position',[0.6 0.65 (z3ax(2)-z3ax(1))*sct*10 (z3ax(4)-z3ax(3))*sca*10]);
set(gca,'ColorOrder',[0 0 0;0.2 0.2 0.2;0.6 0.6 0.6])
hold all
plot(time2,AB_true_t_2sided_comp,'-',time2,AB_int_mon_t_2sided,'--',time2,AB_int_full_t_2sided,'-.','linewidth',2);
axis(z3ax)
box on
set(z3,'fontsize',8,'XTick',[0.560;0.570],'XTickLabel',[0.560;0.570])
%%%%% Following 8 lines adapted from http://www.mathworks.fr/matlabcentral/newsreader/view_thread/112386
oldLabels = str2num(get(gca,'YTickLabel'));
exp = 10^4;
newLabels = num2str(oldLabels);
set(gca,'YTickLabel',newLabels,'units','normalized');
posAxes = get(gca,'position');
textBox = annotation('textbox','linestyle','none','margin',1,'string',['x 10^{' sprintf('%d',log10(1./exp)) '}']);
posAn = get(textBox,'position');
set(textBox,'fontsize',8,'position',[posAxes(1) posAxes(2)+posAxes(4) posAn(3) posAn(4)],'VerticalAlignment','bottom','HorizontalAlignment','left');
%%%%%
% Zoom 4
z4ax=[0.655 0.675 -0.1*amaxt -0.05*amaxt];
z4=axes('position',[0.62 0.28 (z4ax(2)-z4ax(1))*sct*10 (z4ax(4)-z4ax(3))*sca*10]);
set(gca,'ColorOrder',[0 0 0;0.2 0.2 0.2;0.6 0.6 0.6])
hold all
plot(time2,AB_true_t_2sided_comp,'-',time2,AB_int_mon_t_2sided,'--',time2,AB_int_full_t_2sided,'-.','linewidth',2);
axis(z4ax)
box on
set(z4,'fontsize',8,'XTick',[0.66;0.67],'XTickLabel',[0.66;0.67])
%%%%% Following 8 lines adapted from http://www.mathworks.fr/matlabcentral/newsreader/view_thread/112386
oldLabels = str2num(get(gca,'YTickLabel'));
exp = 10^4;
newLabels = num2str(oldLabels);
set(gca,'YTickLabel',newLabels,'units','normalized');
posAxes = get(gca,'position');
textBox = annotation('textbox','linestyle','none','margin',1,'string',['x 10^{' sprintf('%d',log10(1./exp)) '}']);
posAn = get(textBox,'position');
set(textBox,'fontsize',8,'position',[posAxes(1) posAxes(2)+posAxes(4) posAn(3) posAn(4)],'VerticalAlignment','bottom','HorizontalAlignment','left');
%%%%%

legpos = get(leg,'position');
axpos = get(main,'position');
set(leg,'position',[legpos(1) 0.04 legpos(3) legpos(4)])
set(main,'position',axpos)



% %% Save figures using function savefig
% % The savefig function can be downloaded from http://www.mathworks.co.uk/matlabcentral/fileexchange/10889-savefig
% savefig('fig_4_interf_ex1_f1',fig6,'eps','-r300','-crop')
% savefig('fig_5_interf_ex1_f2',fig7,'eps','-r300','-crop')
% 
% %% Convert to tiff using ImageMagick
% % ImageMagick can be downloaded from http://www.imagemagick.org
% system('convert -density 300 -alpha off fig_4_interf_ex1_f1.eps fig_4_interf_ex1_f1.tiff');
% system('convert -density 300 -alpha off fig_5_interf_ex1_f2.eps fig_5_interf_ex1_f2.tiff');
