%% %%% Figures in GEOPHYSICS format %%% %%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This code is distributed as part of the source-code package 
%                   acoustic_modelling_foldy_v.4.1_seg 
% that accompanies Galetti et al. (2013). The package can be downloaded 
% from the Geophysics source-code archive at 
%                   http://software.seg.org/2013/0003
% Use of this code is subject to acceptance of the terms and conditions
% that can be found at http://software.seg.org/disclaimer.txt 
% Copyright 2013 by The Society of Exploration Geophysicists (SEG)
% Reference:
% Galetti, E., Halliday, D., Curtis, A. (2013) A simple and exact acoustic 
% wavefield modelling code for data processing, imaging and interferometry 
% applications. Geophysics.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Figures 6,7,8

clear all
close all

% Read data from ascii files
AB_int_t_2sided = dlmread('fig_6_7_8_data/AB_int_t_2sided.txt','\t');
AB_int_t_2sided_FD = dlmread('fig_6_7_8_data/AB_int_t_2sided_FD.txt','\t');
AB_true_t = dlmread('fig_6_7_8_data/AB_true_t.txt','\t');
AB_true_t_2sided = dlmread('fig_6_7_8_data/AB_true_t_2sided.txt','\t');
AB_true_t_2sided_FD = dlmread('fig_6_7_8_data/AB_true_t_2sided_FD.txt','\t');
AB_true_t_2sided_comp = dlmread('fig_6_7_8_data/AB_true_t_2sided_comp.txt','\t');
AB_true_t_2sided_comp_FD = dlmread('fig_6_7_8_data/AB_true_t_2sided_comp_FD.txt','\t');
AB_true_t_FD = dlmread('fig_6_7_8_data/AB_true_t_FD.txt','\t');
time1 = dlmread('fig_6_7_8_data/time1.txt','\t');
time2 = dlmread('fig_6_7_8_data/time2.txt','\t');
srx = dlmread('fig_6_7_8_data/srx.txt','\t');
rcx = dlmread('fig_6_7_8_data/rcx.txt','\t');


scrnsz = get(0,'screensize');
amaxt=max(max([abs(AB_true_t_2sided),abs(AB_true_t_2sided_FD),abs(AB_int_t_2sided),abs(AB_int_t_2sided_FD)]));


% Plot geometry
fig7=figure;
fig7w=3.33;
fig7h=3.33;
set(fig7,'units','inches','Pos',[1 1 fig7w fig7h])
% Plot
hold on
src=plot(srx(1:6:end,1),srx(1:6:end,2),'k*','markersize',6);
rec=plot(rcx(:,1),rcx(:,2),'kv','markersize',6,'markerfacecolor','k');
axis equal
axis([min(srx(:,1)-50) max(srx(:,1)+50) min(srx(:,2)-50) max(srx(:,2)+50)])
box on
set(gca,'fontsize',8,'XTick',-500:250:500,'YTick',-500:250:500)
xlabel ('x (m)','fontsize',8)
ylabel ('y (m)','fontsize',8)
text(rcx(1,1),rcx(1,2)-50,'A','fontsize',8,'FontAngle','italic','horizontalalignment','center')
text(rcx(2,1),rcx(2,2)-50,'B','fontsize',8,'FontAngle','italic','horizontalalignment','center')

% Plot results: true GF and interferometric GFs 
% Time domain, causal part only and zoomed-in areas
fig8=figure;
fig8w=4.33;
fig8h=6;
set(fig8,'units','inches','Pos',[5 1 fig8w fig8h])
% Complete traces
main1=axes('position',[0.1 0.1 0.8 0.8]);
sca=0.8/(2*amaxt);
sct=0.8/(0.5*max(time2));
hold on
set(gca,'ColorOrder',[0 0 0;0.4 0.4 0.4])
hold all
foldy=plot(time1,AB_true_t,'-','linewidth',2);
fd=plot(time1,AB_true_t_FD,'-.','linewidth',2);
axis([0 0.4*max(time2) -amaxt amaxt])
box on
set(gca,'fontsize',8)
%%%%% Following 8 lines adapted from http://www.mathworks.fr/matlabcentral/newsreader/view_thread/112386
oldLabels = str2num(get(gca,'YTickLabel'));
exp = 10^2;
newLabels = num2str(oldLabels*exp);
set(gca,'YTickLabel',newLabels,'units','normalized');
posAxes = get(gca,'position');
textBox = annotation('textbox','linestyle','none','margin',1,'string',['x 10^{' sprintf('%d',log10(1./exp)) '}']);
posAn = get(textBox,'position');
set(textBox,'fontsize',8,'position',[posAxes(1) posAxes(2)+posAxes(4) posAn(3) posAn(4)],'VerticalAlignment','bottom','HorizontalAlignment','left');
%%%%%
xlabel ('Time (s)','fontsize',8)
ylabel ('Amplitude (pressure)','fontsize',8)
leg1=legend([foldy fd],'True trace (Foldy)','True trace (FD)','location','southeast');
%set(leg1,'fontsize',8)
% Zoom 1
z1ax=[0.243 0.256 0.155*amaxt 0.173*amaxt];
z1=axes('position',[0.18 0.6 (z1ax(2)-z1ax(1))*sct*20 (z1ax(4)-z1ax(3))*sca*20]);
set(gca,'ColorOrder',[0 0 0;0.4 0.4 0.4])
hold all
plot(time1,AB_true_t,'-',time1,AB_true_t_FD,'-.','linewidth',2);
axis(z1ax)
box on
set(z1,'fontsize',8,'XTick',[0.245;0.255],'XTickLabel',[0.245;0.255])
%%%%% Following 8 lines adapted from http://www.mathworks.fr/matlabcentral/newsreader/view_thread/112386
oldLabels = str2num(get(gca,'YTickLabel'));
exp = 10^3;
newLabels = num2str(oldLabels);
set(gca,'YTickLabel',newLabels,'units','normalized');
posAxes = get(gca,'position');
textBox = annotation('textbox','linestyle','none','margin',1,'string',['x 10^{' sprintf('%d',log10(1./exp)) '}']);
posAn = get(textBox,'position');
set(textBox,'fontsize',8,'position',[posAxes(1) posAxes(2)+posAxes(4) posAn(3) posAn(4)],'VerticalAlignment','bottom','HorizontalAlignment','left');
%%%%%
% Zoom 2
z2ax=[0.342 0.346 0.988*amaxt 1.0005*amaxt];
z2=axes('position',[0.53 0.615 (z2ax(2)-z2ax(1))*sct*50 (z2ax(4)-z2ax(3))*sca*50]);
set(gca,'ColorOrder',[0 0 0;0.4 0.4 0.4])
hold all
plot(time1,AB_true_t,'-',time1,AB_true_t_FD,'-.','linewidth',2);
axis(z2ax)
box on
set(z2,'fontsize',8,'XTick',[0.342;0.346],'XTickLabel',[0.342;0.346],'YTick',[0.0198;0.0199;0.02],'YTickLabel',[0.0198;0.0199;0.02])
%%%%% Following 8 lines adapted from http://www.mathworks.fr/matlabcentral/newsreader/view_thread/112386
oldLabels = str2num(get(gca,'YTickLabel'));
exp = 10^2;
newLabels = num2str(oldLabels*exp);
set(gca,'YTickLabel',newLabels,'units','normalized');
posAxes = get(gca,'position');
textBox = annotation('textbox','linestyle','none','margin',1,'string',['x 10^{' sprintf('%d',log10(1./exp)) '}']);
posAn = get(textBox,'position');
set(textBox,'fontsize',8,'position',[posAxes(1) posAxes(2)+posAxes(4) posAn(3) posAn(4)],'VerticalAlignment','bottom','HorizontalAlignment','left');
%%%%%
% Zoom 3
z3ax=[0.296 0.302 -0.767*amaxt -0.754*amaxt];
z3=axes('position',[0.185 0.16 (z3ax(2)-z3ax(1))*sct*35 (z3ax(4)-z3ax(3))*sca*35]);
set(gca,'ColorOrder',[0 0 0;0.4 0.4 0.4])
hold all
plot(time1,AB_true_t,'-',time1,AB_true_t_FD,'-.','linewidth',2);
axis(z3ax)
box on
set(z3,'fontsize',8,'XTick',[0.296;0.302],'XTickLabel',[0.296;0.302])
%%%%% Following 8 lines adapted from http://www.mathworks.fr/matlabcentral/newsreader/view_thread/112386
oldLabels = str2num(get(gca,'YTickLabel'));
exp = 10^2;
newLabels = num2str(oldLabels*exp);
set(gca,'YTickLabel',newLabels,'units','normalized');
posAxes = get(gca,'position');
textBox = annotation('textbox','linestyle','none','margin',1,'string',['x 10^{' sprintf('%d',log10(1./exp)) '}']);
posAn = get(textBox,'position');
set(textBox,'fontsize',8,'position',[posAxes(1) posAxes(2)+posAxes(4) posAn(3) posAn(4)],'VerticalAlignment','bottom','HorizontalAlignment','left');
%%%%%
% Zoom 4
z4ax=[0.387 0.393 -0.445*amaxt -0.432*amaxt];
z4=axes('position',[0.56 0.23 (z4ax(2)-z4ax(1))*sct*35 (z4ax(4)-z4ax(3))*sca*35]);
set(gca,'ColorOrder',[0 0 0;0.4 0.4 0.4])
hold all
plot(time1,AB_true_t,'-',time1,AB_true_t_FD,'-.','linewidth',2);
axis(z4ax)
box on
set(z4,'fontsize',8,'XTick',[0.388;0.392],'XTickLabel',[0.388;0.392])
%%%%% Following 8 lines adapted from http://www.mathworks.fr/matlabcentral/newsreader/view_thread/112386
oldLabels = str2num(get(gca,'YTickLabel'));
exp = 10^3;
newLabels = num2str(oldLabels);
set(gca,'YTickLabel',newLabels,'units','normalized');
posAxes = get(gca,'position');
textBox = annotation('textbox','linestyle','none','margin',1,'string',['x 10^{' sprintf('%d',log10(1./exp)) '}']);
posAn = get(textBox,'position');
set(textBox,'fontsize',8,'position',[posAxes(1) posAxes(2)+posAxes(4) posAn(3) posAn(4)],'VerticalAlignment','bottom','HorizontalAlignment','left');
%%%%%


% Plot results: true GF and interferometric GFs 
% Time domain, causal part only and zoomed-in areas
fig9=figure;
fig9w=4.33;
fig9h=6;
set(fig9,'units','inches','Pos',[10 1 fig9w fig9h])
% Complete traces
main2=axes('position',[0.1 0.1 0.8 0.8]);
sca=0.8/(2*amaxt);
sct=0.8/(0.5*max(time2));
hold on
set(gca,'ColorOrder',[0 0 0;0.6 0.6 0.6;0.2 0.2 0.2])
hold all
true=plot(time2,AB_true_t_2sided_comp,'-','linewidth',2);
int=plot(time2,AB_int_t_2sided,'--','linewidth',2);
int2=plot(time2,AB_int_t_2sided_FD,'-.','linewidth',2);
axis([0 0.4*max(time2) -amaxt amaxt])
box on
set(gca,'fontsize',8)
%%%%% Following 8 lines adapted from http://www.mathworks.fr/matlabcentral/newsreader/view_thread/112386
oldLabels = str2num(get(gca,'YTickLabel'));
exp = 10^2;
newLabels = num2str(oldLabels*exp);
set(gca,'YTickLabel',newLabels,'units','normalized');
posAxes = get(gca,'position');
textBox = annotation('textbox','linestyle','none','margin',1,'string',['x 10^{' sprintf('%d',log10(1./exp)) '}']);
posAn = get(textBox,'position');
set(textBox,'fontsize',8,'position',[posAxes(1) posAxes(2)+posAxes(4) posAn(3) posAn(4)],'VerticalAlignment','bottom','HorizontalAlignment','left');
%%%%%
xlabel ('Time (s)','fontsize',8)
ylabel ('Amplitude (pressure)','fontsize',8)
leg2=legend([true int int2],'True trace (Foldy)','Interferometric trace (Foldy)','Interferometric trace (FD)','location','southeast');
%set(leg2,'fontsize',8)
% Zoom 1
z1ax=[0.243 0.256 0.155*amaxt 0.173*amaxt];
z1=axes('position',[0.18 0.6 (z1ax(2)-z1ax(1))*sct*20 (z1ax(4)-z1ax(3))*sca*20]);
set(gca,'ColorOrder',[0 0 0;0.6 0.6 0.6;0.2 0.2 0.2])
hold all
plot(time2,AB_true_t_2sided_comp,'-',time2,AB_int_t_2sided,'--',time2,AB_int_t_2sided_FD,'-.','linewidth',2);
axis(z1ax)
box on
set(z1,'fontsize',8,'XTick',[0.245;0.255],'XTickLabel',[0.245;0.255])
%%%%% Following 8 lines adapted from http://www.mathworks.fr/matlabcentral/newsreader/view_thread/112386
oldLabels = str2num(get(gca,'YTickLabel'));
exp = 10^3;
newLabels = num2str(oldLabels);
set(gca,'YTickLabel',newLabels,'units','normalized');
posAxes = get(gca,'position');
textBox = annotation('textbox','linestyle','none','margin',1,'string',['x 10^{' sprintf('%d',log10(1./exp)) '}']);
posAn = get(textBox,'position');
set(textBox,'fontsize',8,'position',[posAxes(1) posAxes(2)+posAxes(4) posAn(3) posAn(4)],'VerticalAlignment','bottom','HorizontalAlignment','left');
%%%%%
% Zoom 2
z2ax=[0.342 0.346 0.988*amaxt 1.0005*amaxt];
z2=axes('position',[0.53 0.615 (z2ax(2)-z2ax(1))*sct*50 (z2ax(4)-z2ax(3))*sca*50]);
set(gca,'ColorOrder',[0 0 0;0.6 0.6 0.6;0.2 0.2 0.2])
hold all
plot(time2,AB_true_t_2sided_comp,'-',time2,AB_int_t_2sided,'--',time2,AB_int_t_2sided_FD,'-.','linewidth',2);
axis(z2ax)
box on
set(z2,'fontsize',8,'XTick',[0.342;0.346],'XTickLabel',[0.342;0.346],'YTick',[0.0198;0.0199;0.02],'YTickLabel',[0.0198;0.0199;0.02])
%%%%% Following 8 lines adapted from http://www.mathworks.fr/matlabcentral/newsreader/view_thread/112386
oldLabels = str2num(get(gca,'YTickLabel'));
exp = 10^2;
newLabels = num2str(oldLabels*exp);
set(gca,'YTickLabel',newLabels,'units','normalized');
posAxes = get(gca,'position');
textBox = annotation('textbox','linestyle','none','margin',1,'string',['x 10^{' sprintf('%d',log10(1./exp)) '}']);
posAn = get(textBox,'position');
set(textBox,'fontsize',8,'position',[posAxes(1) posAxes(2)+posAxes(4) posAn(3) posAn(4)],'VerticalAlignment','bottom','HorizontalAlignment','left');
%%%%%
% Zoom 3
z3ax=[0.296 0.302 -0.767*amaxt -0.754*amaxt];
z3=axes('position',[0.185 0.16 (z3ax(2)-z3ax(1))*sct*35 (z3ax(4)-z3ax(3))*sca*35]);
set(gca,'ColorOrder',[0 0 0;0.6 0.6 0.6;0.2 0.2 0.2])
hold all
plot(time2,AB_true_t_2sided_comp,'-',time2,AB_int_t_2sided,'--',time2,AB_int_t_2sided_FD,'-.','linewidth',2);
axis(z3ax)
box on
set(z3,'fontsize',8,'XTick',[0.296;0.302],'XTickLabel',[0.296;0.302])
%%%%% Following 8 lines adapted from http://www.mathworks.fr/matlabcentral/newsreader/view_thread/112386
oldLabels = str2num(get(gca,'YTickLabel'));
exp = 10^2;
newLabels = num2str(oldLabels*exp);
set(gca,'YTickLabel',newLabels,'units','normalized');
posAxes = get(gca,'position');
textBox = annotation('textbox','linestyle','none','margin',1,'string',['x 10^{' sprintf('%d',log10(1./exp)) '}']);
posAn = get(textBox,'position');
set(textBox,'fontsize',8,'position',[posAxes(1) posAxes(2)+posAxes(4) posAn(3) posAn(4)],'VerticalAlignment','bottom','HorizontalAlignment','left');
%%%%%
% Zoom 4
z4ax=[0.387 0.393 -0.445*amaxt -0.432*amaxt];
z4=axes('position',[0.56 0.23 (z4ax(2)-z4ax(1))*sct*35 (z4ax(4)-z4ax(3))*sca*35]);
set(gca,'ColorOrder',[0 0 0;0.6 0.6 0.6;0.2 0.2 0.2])
hold all
plot(time2,AB_true_t_2sided_comp,'-',time2,AB_int_t_2sided,'--',time2,AB_int_t_2sided_FD,'-.','linewidth',2);
axis(z4ax)
box on
set(z4,'fontsize',8,'XTick',[0.388;0.392],'XTickLabel',[0.388;0.392])
%%%%% Following 8 lines adapted from http://www.mathworks.fr/matlabcentral/newsreader/view_thread/112386
oldLabels = str2num(get(gca,'YTickLabel'));
exp = 10^3;
newLabels = num2str(oldLabels);
set(gca,'YTickLabel',newLabels,'units','normalized');
posAxes = get(gca,'position');
textBox = annotation('textbox','linestyle','none','margin',1,'string',['x 10^{' sprintf('%d',log10(1./exp)) '}']);
posAn = get(textBox,'position');
set(textBox,'fontsize',8,'position',[posAxes(1) posAxes(2)+posAxes(4) posAn(3) posAn(4)],'VerticalAlignment','bottom','HorizontalAlignment','left');
%%%%%

set(main1,'position',get(main2,'position'))



% %% Save figures using function savefig
% % The savefig function can be downloaded from http://www.mathworks.co.uk/matlabcentral/fileexchange/10889-savefig
% savefig('fig_6_interf_ex2_f1',fig7,'eps','-r300','-crop')
% savefig('fig_7_interf_ex2_f2',fig8,'eps','-r300','-crop')
% savefig('fig_8_interf_ex2_f3',fig9,'eps','-r300','-crop')
% 
% %% Convert to tiff using ImageMagick
% % ImageMagick can be downloaded from http://www.imagemagick.org
% system('convert -density 300 -alpha off fig_6_interf_ex2_f1.eps fig_6_interf_ex2_f1.tiff');
% system('convert -density 300 -alpha off fig_7_interf_ex2_f2.eps fig_7_interf_ex2_f2.tiff');
% system('convert -density 300 -alpha off fig_8_interf_ex2_f3.eps fig_8_interf_ex2_f3.tiff');
